CA12_Cl05.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Users |
verifyTextPresent | Inicio › Auth › Usuarios |
clickAndWait | link=Añadir usuario |
type | id_username | nuevousuario
type | id_password1 | 1234
type | id_password2 | 1234
clickAndWait | _save |
verifyTextPresent | Inicio › Auth › Usuarios › nuevousuario |
clickAndWait | link=Borrar |
verifyTextPresent | ¿Está seguro de que quiere borrar los usuario "nuevousuario"? Se borrarán los siguientes objetos relacionados: |
clickAndWait | //input[@value='Sí, estoy seguro'] |
verifyTextPresent | Inicio › Auth › Usuarios |
clickAndWait | link=Terminar sesión |